#
# spec file for package mwic
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?license: %global license %doc}
Name:           mwic
Version:        0.7.9
Release:        bp156.2.1
Summary:        A spellchecker with grouping support
License:        MIT
Group:          Productivity/Office/Other
URL:            http://jwilk.net/software/mwic
Source:         https://github.com/jwilk/mwic/releases/download/%{version}/mwic-%{version}.tar.gz
Source1:        https://github.com/jwilk/mwic/releases/download/%{version}/mwic-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  python3-devel >= 3.2
BuildRequires:  python3-docutils
Requires:       python3-pyenchant
Requires:       python3-regex
BuildArch:      noarch

%description
mwic is a spell-checker that groups possible misspellings and shows
them in their contexts. This is useful for checking technical
documents that often contain words that are not included in standard
dictionaries.

%prep
%setup -q

%build
sed -i '1s%^#!.*%#!/usr/bin/python3%' mwic

%install
make DESTDIR=%{buildroot} PREFIX=/usr -C doc
%{make_install} PREFIX=/usr

%files
%doc doc/changelog
%license doc/LICENSE
%{_bindir}/mwic
%{_prefix}/share/mwic
%{_mandir}/man1/mwic.1%{?ext_man}

%changelog
* Sun Jan 15 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.9:
  * Add new multi-word misspellings to the dictionary.
  * Fix printing PyEnchant version.
  * Improve mwic4po:
    + Improve error handling.
    + Use uppercase for CLI metavar.
  * Drop support for Python < 3.6.
  * Update Docutils homepage URL.
  * Make it possible use pytest as the test harness.
* Mon Mar 30 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 0.7.8:
  * Add new multi-word misspellings to the dictionary.
  * Use the \e[90m sequence for dark gray.
  * Improve the build system:
    + Check Python version on install.
    + Byte-compile Python code on install.
    https://github.com/jwilk/mwic/issues/9
    + Don't require GNU install(1).
  * Rephrase descriptions of --help and --version in help messages.
  * Improve the test suite.
* Tue Nov 13 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove reproducible-manpage.patch
- update to version 0.7.7:
  * no upstream changelog available
* Sat Oct 13 2018 Sebastian Wagner <sebix+novell.com@sebix.at>
- add reproducible-manpage.patch
- update to version 0.7.6:
  * no upstream changelog available
* Wed Aug  8 2018 jengelh@inai.de
- Update summary so it's a bit more useful in lists like yast's.
- Wrap description.
* Wed May  2 2018 sebix+novell.com@sebix.at
- update to version 0.7.5:
  * Update PyPI URLs in documentation.
  * Update Lintian URLs in the manual page.
* Wed Jan 24 2018 sebix+novell.com@sebix.at
- update to version 0.7.4
  * Add new multi-word misspellings to the dictionary.
  * Reset the SIGPIPE signal disposition.
* Tue Oct 17 2017 sebix+novell.com@sebix.at
- Replace shebang in executable by call to /usr/bin/python3, fixing rpmlint error
* Mon Sep 25 2017 sebix+novell.com@sebix.at
- remove deprecated manual source validation
* Sun Sep 24 2017 sebix+novell.com@sebix.at
- fix source validation
* Sun Sep 24 2017 sebix+novell.com@sebix.at
- use packaged method to install the package
  * remove all patches
- validate source file
* Tue Sep  5 2017 sebix+novell.com@sebix.at
- initial package for version 0.7.3
- add wip-pip.patch from upstream pull request #4 for setup.py
- add allow_setup.py_call.patch allowing to use the setup.py file
